pub struct __Pubkey(/* private fields */);Expand description
The address of a Solana account.
Some account addresses are ed25519 public keys, with corresponding secret
keys that are managed off-chain. Often, though, account addresses do not
have corresponding secret keys — as with program derived
addresses — or the secret key is not relevant to the operation
of a program, and may have even been disposed of. As running Solana programs
can not safely create or manage secret keys, the full Keypair is not
defined in solana-program but in solana-sdk.
Implementations
Sourceimpl Address
impl Address
pub const fn new_from_array(address_array: [u8; 32]) -> Address
Sourcepub const fn from_str_const(s: &str) -> Address
Available on crate feature decode only.
pub const fn from_str_const(s: &str) -> Address
decode only.Decode a string into an Address, usable in a const context
Sourcepub fn new_unique() -> Address
Available on crate feature atomic only.
pub fn new_unique() -> Address
atomic only.Create an unique Address for tests and benchmarks.
pub fn create_with_seed( base: &Address, seed: &str, owner: &Address, ) -> Result<Address, AddressError>
Available on crate feature
sha2 only.pub const fn to_bytes(&self) -> [u8; 32]